@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010-2013 Raphaël Barrois
+# Copyright (c) 2010-2020 Raphaël Barrois
 # This software is distributed under the two-clause BSD license.
 
 """Common exceptions for fslib."""
 
-from __future__ import absolute_import, unicode_literals
-
 import errno
 
 
@@ -15,7 +13,7 @@ class FSError(OSError):
 
 class DeletedObjectError(OSError):
     def __init__(self, path, **kwargs):
-        super(DeletedObjectError, self).__init__(
+        super().__init__(
             errno.ENOENT,
             "No such file or directory: %r" % path,
             **kwargs
@@ -37,5 +35,3 @@ ENOENT = OSErrorWrapper(errno.ENOENT, "No such file or directory")
 ENOTDIR = OSErrorWrapper(errno.ENOTDIR, "Not a directory")
 ENOTEMPTY = OSErrorWrapper(errno.ENOTEMPTY, "Directory not empty")
 EROFS = OSErrorWrapper(errno.EROFS, "Read-only file system")
-
-
